@@ -23,9 +23,8 @@ def _get_kwargs(
         "url": f"/projects/{project_id}",
     }
 
-    _body = body.to_dict()
+    _kwargs["json"] = body.to_dict()
 
-    _kwargs["json"] = _body
     headers["Content-Type"] = "application/json"
 
     _kwargs["headers"] = headers
@@ -70,7 +69,8 @@ def sync_detailed(
 
      Update a project with passed project_in.
 
-    If srid is changed, then all location values are transformed from the old srid to the new srid.
+    If srid is changed, then all location and cross section values are transformed from the old srid to
+    the new srid.
     The location should not move on the map.
 
     Args:
@@ -108,7 +108,8 @@ def sync(
 
      Update a project with passed project_in.
 
-    If srid is changed, then all location values are transformed from the old srid to the new srid.
+    If srid is changed, then all location and cross section values are transformed from the old srid to
+    the new srid.
     The location should not move on the map.
 
     Args:
@@ -141,7 +142,8 @@ async def asyncio_detailed(
 
      Update a project with passed project_in.
 
-    If srid is changed, then all location values are transformed from the old srid to the new srid.
+    If srid is changed, then all location and cross section values are transformed from the old srid to
+    the new srid.
     The location should not move on the map.
 
     Args:
@@ -177,7 +179,8 @@ async def asyncio(
 
      Update a project with passed project_in.
 
-    If srid is changed, then all location values are transformed from the old srid to the new srid.
+    If srid is changed, then all location and cross section values are transformed from the old srid to
+    the new srid.
     The location should not move on the map.
 
     Args:
